aboutsummaryrefslogtreecommitdiff
path: root/lisp/mastodon-tl.el
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/mastodon-tl.el')
-rw-r--r--lisp/mastodon-tl.el5
1 files changed, 3 insertions, 2 deletions
diff --git a/lisp/mastodon-tl.el b/lisp/mastodon-tl.el
index c791f7e..6c1a771 100644
--- a/lisp/mastodon-tl.el
+++ b/lisp/mastodon-tl.el
@@ -1908,9 +1908,10 @@ LANGS is the accumulated array param alist if we re-run recursively."
;; fetch 'toot-json:
(list (alist-get 'acct
(mastodon-tl--property 'toot-json :no-move))))
;; profile view, no toots
;; needed for e.g. gup.pe groups which show no toots publically:
- ((mastodon-tl--profile-buffer-p)
+ ((and (mastodon-tl--profile-buffer-p)
+ (get-text-property (point) 'profile-json))
(list (alist-get 'acct
(mastodon-profile--profile-json))))
(t
@@ -1908,9 +1908,10 @@ LANGS is the accumulated array param alist if we re-run recursively."
(list (alist-get 'acct
(mastodon-tl--property 'toot-json :no-move))))
- ;; profile view, no toots
+ ;; profile view, point in profile details, poss no toots
;; needed for e.g. gup.pe groups which show no toots publically: